@@ -1,11 +1,11 @@
 from .packages import find_package, find_packages, group_search, installed_package, list_available_packages, package_search, validate_package_list
 
 __all__ = [
-	"find_package",
-	"find_packages",
-	"group_search",
-	"installed_package",
-	"list_available_packages",
-	"package_search",
-	"validate_package_list",
+	'find_package',
+	'find_packages',
+	'group_search',
+	'installed_package',
+	'list_available_packages',
+	'package_search',
+	'validate_package_list',
 ]
