@@ -12,7 +12,7 @@ from archinstall.tui.types import Alignment, FrameProperties, Orientation
 from ..hardware import GfxDriver
 from ..interactions.system_conf import select_driver
 from ..menu.abstract_menu import AbstractSubMenu
-from ..models.profile_model import ProfileConfiguration
+from ..models.profile import ProfileConfiguration
 
 
 class ProfileMenu(AbstractSubMenu[ProfileConfiguration]):
@@ -64,8 +64,8 @@ class ProfileMenu(AbstractSubMenu[ProfileConfiguration]):
 		]
 
 	@override
-	def run(self) -> ProfileConfiguration | None:
-		super().run()
+	def run(self, additional_title: str | None = None) -> ProfileConfiguration | None:
+		super().run(additional_title=additional_title)
 		return self._profile_config
 
 	def _select_profile(self, preset: Profile | None) -> Profile | None:
@@ -237,5 +237,3 @@ def select_profile(
 					pass
 
 			return current_profile
-
-	return None
